@@ -49,8 +49,8 @@ static const KeyBinding bindings_motions[] = {
 	{ "b",                  ACTION(CURSOR_WORD_START_PREV)              },
 	{ "E",                  ACTION(CURSOR_LONGWORD_END_NEXT)            },
 	{ "e",                  ACTION(CURSOR_WORD_END_NEXT)                },
-	{ "F",                  ACTION(TO_LEFT)                             },
-	{ "f",                  ACTION(TO_RIGHT)                            },
+	{ "F",                  ACTION(TO_LINE_LEFT)                        },
+	{ "f",                  ACTION(TO_LINE_RIGHT)                       },
 	{ "go",                 ACTION(CURSOR_BYTE)                         },
 	{ "gH",                 ACTION(CURSOR_BYTE_LEFT)                    },
 	{ "gL",                 ACTION(CURSOR_BYTE_RIGHT)                   },
@@ -75,8 +75,8 @@ static const KeyBinding bindings_motions[] = {
 	{ "M",                  ACTION(CURSOR_WINDOW_LINE_MIDDLE)           },
 	{ "n",                  ACTION(CURSOR_SEARCH_REPEAT_FORWARD)        },
 	{ "N",                  ACTION(CURSOR_SEARCH_REPEAT_BACKWARD)       },
-	{ "T",                  ACTION(TILL_LEFT)                           },
-	{ "t",                  ACTION(TILL_RIGHT)                          },
+	{ "T",                  ACTION(TILL_LINE_LEFT)                      },
+	{ "t",                  ACTION(TILL_LINE_RIGHT)                     },
 	{ "W",                  ACTION(CURSOR_LONGWORD_START_NEXT)          },
 	{ "w",                  ACTION(CURSOR_WORD_START_NEXT)              },
 	{ 0 /* empty last element, array terminator */                      },
@@ -285,6 +285,8 @@ static const KeyBinding bindings_readline[] = {
 	{ "<C-u>",              ACTION(DELETE_LINE_BEGIN)                   },
 	{ "<C-v>",              ACTION(INSERT_VERBATIM)                     },
 	{ "<C-w>",              ACTION(DELETE_WORD_PREV)                    },
+	{ "<C-e>",              ACTION(CURSOR_LINE_END)                     },
+	{ "<C-a>",              ACTION(CURSOR_LINE_START)                   },
 	{ "<Delete>",           ACTION(DELETE_CHAR_NEXT)                    },
 	{ "<Escape>",           ACTION(MODE_NORMAL)                         },
 	{ 0 /* empty last element, array terminator */                      },
