@@ -145,7 +145,7 @@ static bool cmd_user(Vis*, Win*, Command*, const char *argv[], Selection*, Filer
 
 static const CommandDef cmds[] = {
 	//      name            help
-	//      flags, default command, implemenation
+	//      flags, default command, implementation
 	{
 		"a",            VIS_HELP("Append text after range")
 		CMD_TEXT, NULL, cmd_append
@@ -278,7 +278,7 @@ typedef struct {
 	const char *names[3];            /* name and optional alias */
 	enum VisOption flags;            /* option type, etc. */
 	VIS_HELP_DECL(const char *help;) /* short, one line help text */
-	VisOptionFunction *func;         /* option handler, NULL for bulitins */
+	VisOptionFunction *func;         /* option handler, NULL for builtins */
 	void *context;                   /* context passed to option handler function */
 } OptionDef;
 
@@ -1393,14 +1393,13 @@ static int extract(Vis *vis, Win *win, Command *cmd, const char *argv[], Selecti
 	Text *txt = win->file->text;
 
 	if (cmd->regex) {
-		bool trailing_match = false;
-		size_t start = range->start, end = range->end, last_start = EPOS;
+		size_t start = range->start, end = range->end;
+		size_t last_start = argv[0][0] == 'x' ? EPOS : start;
 		size_t nsub = 1 + text_regex_nsub(cmd->regex);
 		if (nsub > MAX_REGEX_SUB)
 			nsub = MAX_REGEX_SUB;
 		RegexMatch match[MAX_REGEX_SUB];
-		while (start < end || trailing_match) {
-			trailing_match = false;
+		while (start <= end) {
 			char c;
 			int flags = start > range->start &&
 			            text_byte_get(txt, start - 1, &c) && c != '\n' ?
@@ -1413,7 +1412,7 @@ static int extract(Vis *vis, Win *win, Command *cmd, const char *argv[], Selecti
 				if (argv[0][0] == 'x')
 					r = text_range_new(match[0].start, match[0].end);
 				else
-					r = text_range_new(start, match[0].start);
+					r = text_range_new(last_start, match[0].start);
 				if (match[0].start == match[0].end) {
 					if (last_start == match[0].start) {
 						start++;
@@ -1424,16 +1423,17 @@ static int extract(Vis *vis, Win *win, Command *cmd, const char *argv[], Selecti
 					 * matches the zero-length string immediately after a
 					 * newline. Try filtering out the last such match at EOF.
 					 */
-					if (end == match[0].start && start > range->start)
+					if (end == match[0].start && start > range->start &&
+					    text_byte_get(txt, end-1, &c) && c == '\n')
 						break;
+					start = match[0].end + 1;
+				} else {
+					start = match[0].end;
 				}
-				start = match[0].end;
-				if (start == end)
-					trailing_match = true;
 			} else {
 				if (argv[0][0] == 'y')
 					r = text_range_new(start, end);
-				start = end;
+				start = end + 1;
 			}
 
 			if (text_range_valid(&r)) {
@@ -1442,12 +1442,14 @@ static int extract(Vis *vis, Win *win, Command *cmd, const char *argv[], Selecti
 						Register *reg = &vis->registers[VIS_REG_AMPERSAND+i];
 						register_put_range(vis, reg, txt, &match[i]);
 					}
+					last_start = match[0].end;
+				} else {
+					last_start = start;
 				}
 				if (simulate)
 					count++;
 				else
 					ret &= sam_execute(vis, win, cmd->cmd, NULL, &r);
-				last_start = start;
 			}
 		}
 	} else {
